# PyDID

[![pypi release](https://img.shields.io/pypi/v/pydid)](https://pypi.org/project/pydid/)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

Python library for validating, constructing, and representing DIDs and DID Documents.

## Installation

Using a virtual environment is generally recommended:

```sh
$ python -m venv env
$ source env/bin/activate
```

Install with pip:

```sh
$ pip install pydid
```

## Development

This project is managed with [Poetry](https://python-poetry.org/).

To begin making code changes, clone this repo and do the following to install
dependencies:

```sh
$ python -m venv env
$ source env/bin/activate
$ pip install poetry
$ poetry install
```


## Contributing

See [CONTRIBUTING.md](CONTRIBUTING.md).
